﻿//----------------------------------------------------------------------------
// Preconditions:
// 1. Start Microsoft Visual Studio.
//    a. Click File > New > Project > Visual C# > Windows Forms Application.
//    b. Type BatchUnlockFiles_CSharp in Name.
//    c. Click Browse and navigate to the folder where to create the project.
//    d. Click OK.
//    e. Click Show All Files in the Solution Explorer toolbar and expand
//       Form1.cs in the Solution Explorer.
//    f. Replace the code in Form1.cs with this code.
//    g. To create the form, replace the code in Form1.Designer.cs with
//       this code.
// 2. Add EPDM.Interop.epdm.dll as a reference (right-click the project
//    name in the Solution Explorer, click Add Reference, click
//    Assemblies > Framework in the left-side panel, browse to the top folder of
//    your SOLIDWORKS PDM Professional installation, locate and click
//    EPDM.Interop.epdm.dll, click Open, and click Add).
// 3. Right-click EPDM.Interop.epdm in References, click Properties, and set
//    Embed Interop Types to False to handle methods that pass arrays of
//    structures.
// 4. Check out a vault file.
// 5. Click Debug > Start Debugging or press F5.
//
// Postconditions: 
// 1. Displays the Check In Files dialog box.
//    a. Select a vault view.
//    b. Click Select files to check out from vault.
//    c. In the Select File dialog:
//       1. Click the checked-out vault file.
//       2. Click Open.
//    d. Click Check in files.
//    e. Displays the Check in dialog box with the Reload or Close Files
//       after Check In dropdown in the toolbar.
//    f. Click the Check in button.
//    g. Click OK in the message box.
// 2. Close the Check In Files dialog box.
// 3. Observe that the selected file is checked in to the selected vault.
//----------------------------------------------------------------------------


//Form1.cs

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using EPDM.Interop.epdm;


namespace BatchUnlockFiles_CSharp
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }
        private IEdmVault5 vault1 = null;
        IEdmBatchUnlock2 batchUnlocker;
        IEdmSelectionList6 fileList = null;
        EdmSelectionObject poSel;
        EdmSelItem[] ppoSelection = new EdmSelItem[11];
        int fileCount = 0;
        IEdmFile5 aFile;
        IEdmFolder5 aFolder;
        IEdmFolder5 ppoRetParentFolder;
        IEdmPos5 aPos;
        string str;

        bool retVal;

        public void Form1_Load(System.Object sender, System.EventArgs e)
        {
            try
            {
                IEdmVault5 vault1 = new EdmVault5();
                IEdmVault8 vault = (IEdmVault8)vault1;
                EdmViewInfo[] Views = null;

                vault.GetVaultViews(out Views, false);
                VaultsComboBox.Items.Clear();
                foreach (EdmViewInfo View in Views)
                {
                    VaultsComboBox.Items.Add(View.mbsVaultName);
                }
                if (VaultsComboBox.Items.Count > 0)
                {
                    VaultsComboBox.Text = (string)VaultsComboBox.Items[0];
                }
            }
            catch (System.Runtime.InteropServices.COMException ex)
            {
                MessageBox.Show("HRESULT = 0x" + ex.ErrorCode.ToString("X") + " " + ex.Message);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        public void SelectFiles_Click(System.Object sender, System.EventArgs e)
        {
            try
            {

                IEdmVault7 vault2 = null;
                if (vault1 == null)
                {
                    vault1 = new EdmVault5();
                }
                vault2 = (IEdmVault7)vault1;

                if (!vault1.IsLoggedIn)
                {
                    vault1.LoginAuto(VaultsComboBox.Text, this.Handle.ToInt32());
                }

                //Set the initial directory in the Select File dialog
                OpenFileDialog1.InitialDirectory = vault1.RootFolderPath;
                //Show the Select File dialog
                //System.Windows.Forms.DialogResult DialogResult;
               // DialogResult = OpenFileDialog1.ShowDialog();

                batchUnlocker = (IEdmBatchUnlock2)vault2.CreateUtility(EdmUtility.EdmUtil_BatchUnlock);

                //Convert the selected files to an
                //array of EdmSelItem structs
                int nbrFiles = 1;
                //nbrFiles = OpenFileDialog1.FileNames.Count();
                Array.Resize(ref ppoSelection, nbrFiles);

                //If the user did not click Open, no files selected
                //if (!(DialogResult == System.Windows.Forms.DialogResult.OK))
                //{
                    // do nothing
                //}
                //else
                //{
                  //  int i = 0;
                    //foreach (string FileName in OpenFileDialog1.FileNames)
                    //{
                      //  File1List.Items.Add(FileName);
                        //aFile = vault1.GetFileFromPath(FileName, out ppoRetParentFolder);
                        //aPos = aFile.GetFirstFolderPosition();
                        //aFolder = aFile.GetNextFolder(aPos);
                        ppoSelection[0] = new EdmSelItem();
                        ppoSelection[0].mlDocID = 944632;  // hard coded file id
                        ppoSelection[0].mlProjID = 2039; // hard coded folder id
                        //i = i + 1;
                    //}
                    // Add selections to the batch of files to check in
                    batchUnlocker.AddSelection((EdmVault5)vault1, ref ppoSelection);
              //  }

            }
            catch (System.Runtime.InteropServices.COMException ex)
            {
                MessageBox.Show("HRESULT = 0x" + ex.ErrorCode.ToString("X") + " " + ex.Message);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }


        public void BatchUnlock_Click(System.Object sender, System.EventArgs e)
        {

            try
            {
                IEdmVault7 vault2 = null;
                if (vault1 == null)
                {
                    vault1 = new EdmVault5();
                }
                vault2 = (IEdmVault7)vault1;
                if (!vault1.IsLoggedIn)
                {
                    vault1.LoginAuto(VaultsComboBox.Text, this.Handle.ToInt32());
                }


                if ((batchUnlocker != null))
                {
                    batchUnlocker.CreateTree(this.Handle.ToInt32(), (int)EdmUnlockBuildTreeFlags.Eubtf_ShowCloseAfterCheckinOption + (int)EdmUnlockBuildTreeFlags.Eubtf_MayUnlock);

                    batchUnlocker.Comment = "Updates";
                    fileList = (IEdmSelectionList6)batchUnlocker.GetFileList((int)EdmUnlockFileListFlag.Euflf_GetUnlocked + (int)EdmUnlockFileListFlag.Euflf_GetUndoLocked + (int)EdmUnlockFileListFlag.Euflf_GetUnprocessed);

                    aPos = fileList.GetHeadPosition();

                    str = "Getting " + fileCount + " files: ";
                    while (!(aPos.IsNull))
                    {
                        fileList.GetNext2(aPos, out poSel);
                        str = str + "\r\n" + poSel.mbsPath;
                    }

                    //MessageBox.Show(str)

                    retVal = batchUnlocker.ShowDlg(this.Handle.ToInt32());

                    object statuses = null;
                    if ((retVal))
                    {
                        batchUnlocker.UnlockFiles(this.Handle.ToInt32(), null);
                        statuses = batchUnlocker.GetStatus((int)EdmUnlockStatusFlag.Eusf_CloseAfterCheckinFlag);
                        MessageBox.Show("Close Files after Check In selected? " + statuses);
                    }

                }

            }
            catch (System.Runtime.InteropServices.COMException ex)
            {
                MessageBox.Show("HRESULT = 0x" + ex.ErrorCode.ToString("X") + " " + ex.Message);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }

        }
    }
}



